Enum Mood

pub enum Mood {
    Happy,
    Lonely,
    Errory,
    Scared,
    Unwelcome,
}
The close command accepts an optional “mood” string: this allows clients to tell the server (in general terms) about their experiences with the wormhole interaction. The server records the mood in its “usage” record, so the server operator can get a sense of how many connections are succeeding and failing. The moods currently recognized by the Mailbox server are:

Variants



Happy

The PAKE key-establishment worked, and the client saw at least one valid encrypted message from its peer



Lonely

The client gave up without hearing anything from its peer



Errory

The client encountered some other error: protocol problem or internal error



Scared

The client saw an invalid encrypted message from its peer, indicating that either the wormhole code was typed in wrong, or an attacker tried (and failed) to guess the code



Unwelcome

Clients are not welcome on the server right now