#[non_exhaustive]pub enum RendezvousError {
ProtocolJson(Error),
Protocol(Box<str>),
Server(Box<str>),
Login(Vec<String>),
IO(Error),
}Expand description
An error occurred when connecting to the rendezvous server
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ProtocolJson(Error)
Some deserialization went wrong, we probably got some garbage
Protocol(Box<str>)
A generic string message for “something went wrong”, i.e. the server sent some bullshit message order
Server(Box<str>)
The server sent us an error message
Login(Vec<String>)
Server wants a login permission, but we don’t suppport any of these
IO(Error)
Websocket I/O error