pub struct Key<P: KeyPurpose>(/* private fields */);Expand description
The symmetric encryption key used to communicate with the other side.
You don’t need to do any crypto, but you might need it to derive subkeys for sub-protocols.
Implementations