pub async fn send_folder<N, M, G, H>(
wormhole: Wormhole,
relay_hints: Vec<RelayHint>,
folder_path: N,
folder_name: M,
transit_abilities: Abilities,
transit_handler: G,
progress_handler: H,
cancel: impl Future<Output = ()>,
) -> Result<(), TransferError>Expand description
Send a folder to the other side This isn’t a proper folder transfer as per the Wormhole protocol because it sends it in a way so that the receiver still has to manually unpack it. But it’s better than nothing