Struct magic_wormhole::transfer::AppVersion
source · [−]pub struct AppVersion {}Expand description
The application specific version information for this protocol.
At the moment, this always is an empty object, but this will likely change in the future.