pub struct ReceiveRequest { /* private fields */ }Expand description
Implementations
Sourceimpl ReceiveRequest
impl ReceiveRequest
Sourcepub async fn accept<F, G, W>(
self,
transit_handler: G,
progress_handler: F,
content_handler: &mut W,
cancel: impl Future<Output = ()>,
) -> Result<(), TransferError>
pub async fn accept<F, G, W>( self, transit_handler: G, progress_handler: F, content_handler: &mut W, cancel: impl Future<Output = ()>, ) -> Result<(), TransferError>
Accept the file offer
This will transfer the file and save it on disk.
Sourcepub async fn reject(self) -> Result<(), TransferError>
pub async fn reject(self) -> Result<(), TransferError>
Reject the file offer
This will send an error message to the other side so that it knows the transfer failed.