#[non_exhaustive]pub enum TransitError {
Crypto,
Nonce(Box<[u8]>, Box<[u8]>),
IO(Error),
}Expand description
An error occurred during transit
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Crypto
Cryptography error. This is probably an implementation bug, but may also be caused by an attack
Nonce(Box<[u8]>, Box<[u8]>)
Wrong nonce received, got {:x?} but expected {:x?}. This is probably an implementation bug, but may also be caused by an attack
IO(Error)
I/O error