pub enum TransitRole {
Leader,
Follower,
}Expand description
The role a party takes in a transit connection handshake.
(Despite the handshake being asymmetric, the resulting connection is symmetric.)
Variants
Leader
The leader role in the handshake, formerly called “sender”.
Follower
The follower role in the handshake, formerly called “receiver”.