Struct magic_wormhole::transit::TransitInfo

source ·
#[non_exhaustive]
pub struct TransitInfo { pub conn_type: ConnectionType, pub peer_addr: SocketAddr, }
Metadata for the established transit connection

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
conn_type: ConnectionType

Whether we are connected directly or via a relay server

peer_addr: SocketAddr

Target address of our connection. This may be our peer, or the relay server. This says nothing about the actual transport protocol used.