pub struct TransitRxKey;๐Deprecated since 0.7.0: This will be a private type in the future. Open an issue if you require access to protocol intrinsics in the future
Deprecated: This will be a private type in the future. Open an issue if you require access to protocol intrinsics in the future