Enum Mood Copy item path Source pub enum Mood {
Happy,
Lonely,
Errory,
Scared,
Unwelcome,
}Expand description The close command accepts an optional “mood” string: this allows clients to tell the server
(in general terms) about their experiences with the wormhole interaction. The server records
the mood in its “usage” record, so the server operator can get a sense of how many connections
are succeeding and failing. The moods currently recognized by the Mailbox server are:
The PAKE key-establishment worked, and the client saw at least one valid encrypted message from its peer
The client gave up without hearing anything from its peer
The client encountered some other error: protocol problem or internal error
The client saw an invalid encrypted message from its peer,
indicating that either the wormhole code was typed in wrong,
or an attacker tried (and failed) to guess the code
Clients are not welcome on the server right now
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Deserialize this value from the given Serde deserializer.
Read more Formats the value using the given formatter.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Serialize this value into the given Serde serializer.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dst.
Read more Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more Converts the given value to a
String.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.