pub struct ConnectOffer {
    pub mapping: Vec<(u16, Rc<String>)>,
    /* private fields */
}
A pending forwarding offer from the other side

You should consume this object, either by calling accept or reject.

Fields

mapping: Vec<(u16, Rc<String>)>

Implementations

Accept the offer and start the forwarding

The method will run until an error occurs, the peer terminates the connection or cancel resolves. The last one can be used to provide timeouts or to inject CTRL-C handling. If you want the forward to never (successfully) stop, pass [futures::future::pending()] as the value.

Reject the offer

This will send an error message to the other side so that it knows the transfer failed.