Struct magic_wormhole::forwarding::ConnectOffer
source · [−]Expand description
Fields
mapping: Vec<(u16, Rc<String>)>Implementations
sourceimpl ConnectOffer
impl ConnectOffer
sourcepub async fn accept(
self,
cancel: impl Future<Output = ()>
) -> Result<(), ForwardingError>
pub async fn accept(
self,
cancel: impl Future<Output = ()>
) -> Result<(), ForwardingError>
Accept the offer and start the forwarding
The method will run until an error occurs, the peer terminates the connection
or cancel resolves. The last one can be used to provide timeouts or to inject CTRL-C
handling. If you want the forward to never (successfully) stop, pass [futures::future::pending()]
as the value.
sourcepub async fn reject(self) -> Result<(), ForwardingError>
pub async fn reject(self) -> Result<(), ForwardingError>
Reject the offer
This will send an error message to the other side so that it knows the transfer failed.