Struct magic_wormhole::AppID
source · [−]Expand description
Newtype wrapper for application IDs
The application ID is a string that scopes all commands to that name, effectively separating different protocols on the same rendezvous server.
Tuple Fields
0: Cow<'static, str>Implementations