Enum magic_wormhole::transfer::PeerMessage
source · #[non_exhaustive]pub enum PeerMessage {
Transit(TransitV1),
Offer(OfferMessage),
Answer(AnswerMessage),
Error(String),
Unknown,
}👎Deprecated since 0.7.0: This will be a private type in the future. Open an issue if you require access to protocol intrinsics in the future
The type of message exchanged over the wormhole for this protocol
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Transit(TransitV1)
👎Deprecated since 0.7.0: This will be a private type in the future. Open an issue if you require access to protocol intrinsics in the future
A transit message
Offer(OfferMessage)
👎Deprecated since 0.7.0: This will be a private type in the future. Open an issue if you require access to protocol intrinsics in the future
An offer message
Answer(AnswerMessage)
👎Deprecated since 0.7.0: This will be a private type in the future. Open an issue if you require access to protocol intrinsics in the future
An answer message
Error(String)
👎Deprecated since 0.7.0: This will be a private type in the future. Open an issue if you require access to protocol intrinsics in the future
Tell the other side you got an error
Unknown
👎Deprecated since 0.7.0: This will be a private type in the future. Open an issue if you require access to protocol intrinsics in the future
An unknown message