pub struct ReceiveRequest {
    pub filename: PathBuf,
    pub filesize: u64,
    /* private fields */
}
A pending files send offer from the other side

You should consume this object, either by calling accept or reject.

Fields

filename: PathBuf

Security warning: this is untrusted and unverified input

filesize: u64

Implementations

Accept the file offer

This will transfer the file and save it on disk.

Reject the file offer

This will send an error message to the other side so that it knows the transfer failed.