Struct magic_wormhole::transfer::ReceiveRequest
source · [−]Expand description
Fields
filename: PathBufSecurity warning: this is untrusted and unverified input
filesize: u64Implementations
sourceimpl ReceiveRequest
impl ReceiveRequest
sourcepub async fn accept<F, G, W>(
self,
transit_handler: G,
progress_handler: F,
content_handler: &mut W,
cancel: impl Future<Output = ()>
) -> Result<(), TransferError> where
F: FnMut(u64, u64) + 'static,
G: FnOnce(TransitInfo, SocketAddr),
W: AsyncWrite + Unpin,
pub async fn accept<F, G, W>(
self,
transit_handler: G,
progress_handler: F,
content_handler: &mut W,
cancel: impl Future<Output = ()>
) -> Result<(), TransferError> where
F: FnMut(u64, u64) + 'static,
G: FnOnce(TransitInfo, SocketAddr),
W: AsyncWrite + Unpin,
Accept the file offer
This will transfer the file and save it on disk.
sourcepub async fn reject(self) -> Result<(), TransferError>
pub async fn reject(self) -> Result<(), TransferError>
Reject the file offer
This will send an error message to the other side so that it knows the transfer failed.