pub struct RelayHint {
    pub name: Option<String>,
    pub tcp: HashSet<DirectHint>,
    pub ws: HashSet<Url>,
}
Hint describing a relay server

A server may be reachable at multiple locations. Any two must be relayable over that server, therefore a client may pick only one of these per hint.

All locations are URLs, but here they are already deconstructed and grouped by schema out of convenience.

Fields

name: Option<String>

Human readable name

tcp: HashSet<DirectHint>

TCP endpoints of that relay

ws: HashSet<Url>

WebSockets endpoints of that relay

Implementations