Struct magic_wormhole::transit::RelayHint
source · [−]pub struct RelayHint {
pub name: Option<String>,
pub tcp: HashSet<DirectHint>,
pub ws: HashSet<Url>,
}Expand description
Hint describing a relay server
A server may be reachable at multiple locations. Any two must be relayable over that server, therefore a client may pick only one of these per hint.
All locations are URLs, but here they are already deconstructed and grouped by schema out of convenience.
Fields
name: Option<String>Human readable name
tcp: HashSet<DirectHint>TCP endpoints of that relay
ws: HashSet<Url>WebSockets endpoints of that relay
Implementations
sourceimpl RelayHint
impl RelayHint
pub fn new(
name: Option<String>,
tcp: impl IntoIterator<Item = DirectHint>,
ws: impl IntoIterator<Item = Url>
) -> Self
pub fn from_urls(
name: Option<String>,
urls: impl IntoIterator<Item = Url>
) -> Self
pub fn can_merge(&self, other: &Self) -> bool
pub fn merge(self, other: Self) -> Self
pub fn merge_mut(&mut self, other: Self)
pub fn merge_into(self, collection: &mut Vec<RelayHint>)