pub struct TransitConnector { /* private fields */ }
A partially set up Transit connection.

For the transit handshake, each side generates a Hints with all the information to find the other. You need to exchange it (as in: send yours, receive theirs) with them. This is outside of the transit protocol, because we are protocol agnostic.

Implementations

Send this one to the other side

Connect to the other side, as sender.

Connect to the other side, as receiver